/*-----------------------------------------------------------------------
mcvl_panel_labels.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Labels variables and values
-----------------------------------------------------------------------*/

* Remove any previous value labels
label drop _all

* Order variables
order ua_id_* skill_* date_* sector2d_* contract_*, sequential
order skill occupation sector2d sector3d contract_fixedterm contract_parttime
order migrant_depart migrant_arrive
order ua_id muni_id prov_id ua_1_2 ua_3_5 ua_1_5 ua_smaller
order tenure experience uexp_1_2 uexp_3_5 uexp_smaller uexp_current
order estab_id firm_id
order earnings earnings_capped_ss days_worked_month 
order edu_belowsecondary edu_secondary edu_tertiary edu_code 
order person_id year month date mcvl_wave sex birth_date age birth_prov ss_reg_prov

* Individual characteristics
label var person_id "Individual anonymized identifier"
label var year "Year"
label var month "Month"
label var date "Sequential ordering of months (January 2004 - December 2013)"
label var mcvl_wave "MCVL wave used to extract information"
label var sex "Sex"
label define lbl_sex 1 "Male"
label define lbl_sex 2 "Female", add
label values sex lbl_sex
label var birth_date "Birth year-month"
label var age "Age (years)"
label var birth_prov "Province of birth"
label var ss_reg_prov "Province of social security registration"
* Education
label var edu_belowsecondary "Less than secondary education"
label var edu_secondary "Secondary education"
label var edu_tertiary "University education"
label var edu_code "Education MCVL code"
* Earnings
label var earnings "Total real daily earnings from tax returns (2009 cents of euro)"
label var earnings_capped_ss "Top- and bottom-coded real daily earnings from social security records (2009 cents of euro)"
label var days_worked_month "Days worked in current job in current month"
* Firm establishement identifiers
label var estab_id "Firm establishment anonymized identifier (based on secondary social security contribution account code)"
label var firm_id "Firm anonymized identifier (based on firm tax identification code)"
* Tenure and experience
label var tenure "Tenure in current employer (years)"
label var experience "Experience (years)"
label var uexp_1_2 "Experience in 1st-2nd biggest cities (years)"
label var uexp_3_5 "Experience in 3rd-5th biggest cities (years)" 
label var uexp_smaller "Experience outside 5 biggest cities (years)"
label var uexp_current "Experience in current city (years)"
* Current employer location
label var ua_id "Urban area of current job"
label var muni_id "Municipality of current job"
label var prov_id "Province of current job"
label var ua_1_2 "Current job in 1st-2nd biggest cities"
label var ua_3_5 "Current job in 3rd-5th biggest cities"
label var ua_1_5 "Current job in 1st-5th biggest cities"
label var ua_smaller "Current job outside 5th biggest cities"
* Migration indicators
label var migrant_depart "Last observation prior to migration between urban areas"
label var migrant_arrive "First observation following migration between urban areas"
* Skills
label var skill "Occupational skills"
label define lbl_skill 1 "Very-high-skilled occupation"
label define lbl_skill 2 "High-skilled occupation", add
label define lbl_skill 3 "Medium-high-skilled occupation", add
label define lbl_skill 4 "Medium-low-skilled occupation", add
label define lbl_skill 5 "Low-skilled occupation", add
label values skill lbl_skill
* Skill indicators
label var skill_1 "Very-high-skilled occupation"
label var skill_2 "High-skilled occupation"
label var skill_3 "Medium-high-skilled occupation"
label var skill_4 "Medium-low-skilled occupation"
label var skill_5 "Low-skilled occupation"
* Occupations
label var occupation "Occupation"
label define lbl_occupation 1 "Engineers, college graduates and senior managers"
label define lbl_occupation 2 "Technical engineers and graduate assistants", add
label define lbl_occupation 3 "Administrative and technical managers", add
label define lbl_occupation 4 "Non-graduate assistants", add
label define lbl_occupation 5 "Administrative officers", add
label define lbl_occupation 6 "Subordinates", add
label define lbl_occupation 7 "Administrative assistants", add
label define lbl_occupation 8 "First and second class officers", add
label define lbl_occupation 9 "Third class officers and technicians", add
label define lbl_occupation 10 "Labourers", add
label values occupation lbl_occupation
* Sector
label var sector3d "3-digit sector code (CNAE93)"
label var sector2d "2-digit sector code (CNAE93)"
* Contract indicators
label var contract_parttime "Part-time contract"
label var contract_fixedterm "Fixed-term contract"

* Urban areas
label define lbl_ua 1 "Madrid"
label define lbl_ua 2 "Barcelona", add
label define lbl_ua 3 "València", add
label define lbl_ua 4 "Sevilla", add
label define lbl_ua 5 "Málaga", add
label define lbl_ua 7 "Asturias", add
label define lbl_ua 8 "Zaragoza", add
label define lbl_ua 9 "Alacant - Elx", add
label define lbl_ua 10 "Bahía de Cadiz", add
label define lbl_ua 11 "Murcia", add
label define lbl_ua 12 "Vigo - Pontevedra", add
label define lbl_ua 13 "Las Palmas de Gran Canaria", add
label define lbl_ua 14 "Palma de Mallorca", add
label define lbl_ua 15 "Granada", add
label define lbl_ua 16 "Santa Cruz de Tenerife - La Laguna", add
label define lbl_ua 17 "A Coruña", add
label define lbl_ua 18 "Valladolid", add
label define lbl_ua 20 "Tarragona - Reus", add
label define lbl_ua 22 "Córdoba", add
label define lbl_ua 23 "Santander - Torrelavega", add
label define lbl_ua 24 "Castellò de la Plana", add
label define lbl_ua 26 "Bahía de Algeciras", add
label define lbl_ua 27 "Costa Blanca", add
label define lbl_ua 28 "Cartagena", add
label define lbl_ua 29 "Almería", add
label define lbl_ua 30 "Costa del Sol", add
label define lbl_ua 31 "León", add
label define lbl_ua 32 "Salamanca", add
label define lbl_ua 33 "Gran Canaria Sur", add
label define lbl_ua 34 "Burgos", add
label define lbl_ua 35 "Huelva", add
label define lbl_ua 36 "Logroño", add
label define lbl_ua 37 "Tenerife Sur", add
label define lbl_ua 38 "Albacete", add
label define lbl_ua 39 "Lleida", add
label define lbl_ua 40 "Badajoz", add
label define lbl_ua 41 "Girona", add
label define lbl_ua 42 "Guadalajara", add
label define lbl_ua 43 "Jaén", add
label define lbl_ua 44 "Santiago de Compostela", add
label define lbl_ua 45 "Ferrol", add
label define lbl_ua 46 "Gandía", add
label define lbl_ua 47 "Ourense", add
label define lbl_ua 48 "Torrevieja", add
label define lbl_ua 49 "Toledo", add
label define lbl_ua 50 "Denia - Jávea", add
label define lbl_ua 51 "Valle de la Orotava", add
label define lbl_ua 52 "Orihuela", add
label define lbl_ua 53 "Cáceres", add
label define lbl_ua 54 "Manresa", add
label define lbl_ua 55 "Palencia", add
label define lbl_ua 56 "Talavera de la Reina", add
label define lbl_ua 57 "Lugo", add
label define lbl_ua 58 "Lorca", add
label define lbl_ua 59 "Elda - Petrer", add
label define lbl_ua 60 "Ciudad Real", add
label define lbl_ua 61 "Ponferrada", add
label define lbl_ua 62 "Blanes - Lloret de Mar", add
label define lbl_ua 63 "Vélez-Málaga", add
label define lbl_ua 64 "Alcoi", add
label define lbl_ua 65 "El Ejido", add
label define lbl_ua 66 "Roquetas de Mar", add
label define lbl_ua 68 "Segovia", add
label define lbl_ua 70 "Sagunt", add
label define lbl_ua 71 "Zamora", add
label define lbl_ua 72 "Mérida", add
label define lbl_ua 73 "Sanlucar de Barrameda", add
label define lbl_ua 74 "Linares", add
label define lbl_ua 76 "Motril", add
label define lbl_ua 77 "Arrecife", add
label define lbl_ua 78 "Ávila", add
label define lbl_ua 79 "Cuenca", add
label define lbl_ua 80 "Aranjuez", add
label define lbl_ua 81 "Puertollano", add
label define lbl_ua 82 "Huesca", add
label define lbl_ua 83 "Utrera", add
label values ua_id lbl_ua

* Urban area indicators
label var ua_id_1 "Madrid"
label var ua_id_2 "Barcelona"
label var ua_id_3 "València"
label var ua_id_4 "Sevilla"
label var ua_id_5 "Málaga"
label var ua_id_7 "Asturias"
label var ua_id_8 "Zaragoza"
label var ua_id_9 "Alacant - Elx"
label var ua_id_10 "Bahía de Cadiz"
label var ua_id_11 "Murcia"
label var ua_id_12 "Vigo - Pontevedra"
label var ua_id_13 "Las Palmas de Gran Canaria"
label var ua_id_14 "Palma de Mallorca"
label var ua_id_15 "Granada"
label var ua_id_16 "Santa Cruz de Tenerife - La Laguna"
label var ua_id_17 "A Coruña"
label var ua_id_18 "Valladolid"
label var ua_id_20 "Tarragona - Reus"
label var ua_id_22 "Córdoba"
label var ua_id_23 "Santander - Torrelavega"
label var ua_id_24 "Castellò de la Plana"
label var ua_id_26 "Bahía de Algeciras"
label var ua_id_27 "Costa Blanca"
label var ua_id_28 "Cartagena"
label var ua_id_29 "Almería"
label var ua_id_30 "Costa del Sol"
label var ua_id_31 "León"
label var ua_id_32 "Salamanca"
label var ua_id_33 "Gran Canaria Sur"
label var ua_id_34 "Burgos"
label var ua_id_35 "Huelva"
label var ua_id_36 "Logroño"
label var ua_id_37 "Tenerife Sur"
label var ua_id_38 "Albacete"
label var ua_id_39 "Lleida"
label var ua_id_40 "Badajoz"
label var ua_id_41 "Girona"
label var ua_id_42 "Guadalajara"
label var ua_id_43 "Jaén"
label var ua_id_44 "Santiago de Compostela"
label var ua_id_45 "Ferrol"
label var ua_id_46 "Gandía"
label var ua_id_47 "Ourense"
label var ua_id_48 "Torrevieja"
label var ua_id_49 "Toledo"
label var ua_id_50 "Denia - Jávea"
label var ua_id_51 "Valle de la Orotava"
label var ua_id_52 "Orihuela"
label var ua_id_53 "Cáceres"
label var ua_id_54 "Manresa"
label var ua_id_55 "Palencia"
label var ua_id_56 "Talavera de la Reina"
label var ua_id_57 "Lugo"
label var ua_id_58 "Lorca"
label var ua_id_59 "Elda - Petrer"
label var ua_id_60 "Ciudad Real"
label var ua_id_61 "Ponferrada"
label var ua_id_62 "Blanes - Lloret de Mar"
label var ua_id_63 "Vélez - Málaga"
label var ua_id_64 "Alcoi"
label var ua_id_65 "El Ejido"
label var ua_id_66 "Roquetas de Mar"
label var ua_id_68 "Segovia"
label var ua_id_70 "Sagunt"
label var ua_id_71 "Zamora"
label var ua_id_72 "Mérida"
label var ua_id_73 "Sanlucar de Barrameda"
label var ua_id_74 "Linares"
label var ua_id_76 "Motril"
label var ua_id_77 "Arrecife"
label var ua_id_78 "Ávila"
label var ua_id_79 "Cuenca"
label var ua_id_80 "Aranjuez"
label var ua_id_81 "Puertollano"
label var ua_id_82 "Huesca"
label var ua_id_83 "Utrera"

* Province
label define lbl_prov 1 "Araba"
label define lbl_prov 2 "Albacete", add
label define lbl_prov 3 "Alacant", add
label define lbl_prov 4 "Almería", add
label define lbl_prov 5 "Ávila", add
label define lbl_prov 6 "Badajoz", add
label define lbl_prov 7 "Illes Balears", add
label define lbl_prov 8 "Barcelona", add
label define lbl_prov 9 "Burgos", add
label define lbl_prov 10 "Cáceres", add
label define lbl_prov 11 "Cádiz", add
label define lbl_prov 12 "Castellò", add
label define lbl_prov 13 "Ciudad Real", add
label define lbl_prov 14 "Córdoba", add
label define lbl_prov 15 "A Coruña", add
label define lbl_prov 16 "Cuenca", add
label define lbl_prov 17 "Girona", add
label define lbl_prov 18 "Granada", add
label define lbl_prov 19 "Guadalajara", add
label define lbl_prov 20 "Gipuzkoa", add
label define lbl_prov 21 "Huelva", add
label define lbl_prov 22 "Huesca", add
label define lbl_prov 23 "Jaén", add
label define lbl_prov 24 "León", add
label define lbl_prov 25 "Lleida", add
label define lbl_prov 26 "La Rioja", add
label define lbl_prov 27 "Lugo", add
label define lbl_prov 28 "Madrid", add
label define lbl_prov 29 "Málaga", add
label define lbl_prov 30 "Murcia", add
label define lbl_prov 31 "Navarra", add
label define lbl_prov 32 "Ourense", add
label define lbl_prov 33 "Asturias", add
label define lbl_prov 34 "Palencia", add
label define lbl_prov 35 "Las Palmas", add
label define lbl_prov 36 "Pontevedra", add
label define lbl_prov 37 "Salamanca", add
label define lbl_prov 38 "Santa Cruz de Tenerife", add
label define lbl_prov 39 "Cantabria", add
label define lbl_prov 40 "Segovia", add
label define lbl_prov 41 "Sevilla", add
label define lbl_prov 42 "Soria", add
label define lbl_prov 43 "Tarragona", add
label define lbl_prov 44 "Teruel", add
label define lbl_prov 45 "Toledo", add
label define lbl_prov 46 "València", add
label define lbl_prov 47 "Valladolid", add
label define lbl_prov 48 "Bizkaia", add
label define lbl_prov 49 "Zamora", add
label define lbl_prov 50 "Zaragoza", add
label define lbl_prov 51 "Ceuta", add
label define lbl_prov 52 "Melilla", add
label values birth_prov lbl_prov
label values ss_reg_prov lbl_prov
label values prov_id lbl_prov

* Sectors
label define lbl_sector2d 15 "Manufacture of food products and beverages"
label define lbl_sector2d 16 "Manufacture of tobacco products", add
label define lbl_sector2d 17 "Manufacture of textiles", add
label define lbl_sector2d 18 "Manufacture of wearing apparel; dressing and dyeing of fur", add
label define lbl_sector2d 19 "Tanning and dressing of leather; manufacture of luggage, handbags, saddlery, harness and footwear", add
label define lbl_sector2d 20 "Manufacture of wood and of products of wood and cork, except furniture; manufacture of articles of straw and plaiting materials", add
label define lbl_sector2d 21 "Manufacture of paper and paper products", add
label define lbl_sector2d 22 "Publishing, printing and reproduction of recorded media", add
label define lbl_sector2d 23 "Manufacture of coke, refined petroleum products and nuclear fuel", add
label define lbl_sector2d 24 "Manufacture of chemicals and chemical products", add
label define lbl_sector2d 25 "Manufacture of rubber and plastic products", add
label define lbl_sector2d 26 "Manufacture of other non-metallic mineral products", add
label define lbl_sector2d 27 "Manufacture of basic metals", add
label define lbl_sector2d 28 "Manufacture of fabricated metal products, except machinery and equipment", add
label define lbl_sector2d 29 "Manufacture of mechanical machinery and equipment", add
label define lbl_sector2d 30 "Manufacture of office, accounting and computing machinery", add
label define lbl_sector2d 31 "Manufacture of electrical machinery and apparatus n.e.c.", add
label define lbl_sector2d 32 "Manufacture of radio, television and communication equipment and apparatus", add
label define lbl_sector2d 33 "Manufacture of medical, precision and optical instruments, watches and clocks", add
label define lbl_sector2d 34 "Manufacture of motor vehicles, trailers and semi-trailers", add
label define lbl_sector2d 35 "Manufacture of other transport equipment", add
label define lbl_sector2d 36 "Manufacture of furniture; manufacturing n.e.c." , add
label define lbl_sector2d 37 "Recycling", add
label define lbl_sector2d 40 "Electricity, gas, steam and hot water supply", add
label define lbl_sector2d 41 "Collection, purification and distribution of water", add
label define lbl_sector2d 45 "Construction", add
label define lbl_sector2d 50 "Sale, maintenance and repair of motor vehicles and motorcycles; retail sale of automotive fuel"  , add
label define lbl_sector2d 51 "Wholesale trade and commission trade, except of motor vehicles and motorcycles", add
label define lbl_sector2d 52 "Retail trade, except of motor vehicles and motorcycles; repair of personal and household goods", add
label define lbl_sector2d 55 "Hotels and restaurants", add
label define lbl_sector2d 60 "Land transport; transport via pipelines", add
label define lbl_sector2d 61 "Water transport" , add
label define lbl_sector2d 62 "Air transport", add
label define lbl_sector2d 63 "Supporting and auxiliary transport activities; activities of travel agencies", add
label define lbl_sector2d 64 "Post and telecommunications", add
label define lbl_sector2d 65 "Financial intermediation, except insurance and pension funding", add
label define lbl_sector2d 66 "Insurance and pension funding, except compulsory social security", add
label define lbl_sector2d 67 "Activities auxiliary to financial intermediation", add
label define lbl_sector2d 70 "Real estate activities", add
label define lbl_sector2d 71 "Renting of machinery and equipment without operator and of personal and household goods", add
label define lbl_sector2d 72 "Computer and related activities", add
label define lbl_sector2d 73 "Research and development", add
label define lbl_sector2d 74 "Other business activities", add
label define lbl_sector2d 90 "Sewage and refuse disposal, sanitation and similar activities", add
label define lbl_sector2d 91 "Activities of membership organizations n.e.c.", add
label define lbl_sector2d 92 "Recreational, cultural and sporting activities", add
label define lbl_sector2d 93 "Other service activities", add
label define lbl_sector2d 95 "Activities of private households as employers of domestic staff", add
label values sector2d lbl_sector2d

* Sector indicators
label var sector2d_15 "Manufacture of food products and beverages"
label var sector2d_16 "Manufacture of tobacco products"
label var sector2d_17 "Manufacture of textiles"
label var sector2d_18 "Manufacture of wearing apparel; dressing and dyeing of fur"
label var sector2d_19 "Tanning and dressing of leather; manufacture of luggage, handbags, saddlery, harness and footwear"
label var sector2d_20 "Manufacture of wood and of products of wood and cork, except furniture; manufacture of articles of straw and plaiting materials"
label var sector2d_21 "Manufacture of paper and paper products"
label var sector2d_22 "Publishing, printing and reproduction of recorded media"
label var sector2d_23 "Manufacture of coke, refined petroleum products and nuclear fuel"
label var sector2d_24 "Manufacture of chemicals and chemical products"
label var sector2d_25 "Manufacture of rubber and plastic products"
label var sector2d_26 "Manufacture of other non-metallic mineral products"
label var sector2d_27 "Manufacture of basic metals"
label var sector2d_28 "Manufacture of fabricated metal products, except machinery and equipment"
label var sector2d_29 "Manufacture of mechanical machinery and equipment"
label var sector2d_30 "Manufacture of office, accounting and computing machinery"
label var sector2d_31 "Manufacture of electrical machinery and apparatus n.e.c."
label var sector2d_32 "Manufacture of radio, television and communication equipment and apparatus"
label var sector2d_33 "Manufacture of medical, precision and optical instruments, watches and clocks"
label var sector2d_34 "Manufacture of motor vehicles, trailers and semi-trailers"
label var sector2d_35 "Manufacture of other transport equipment"
label var sector2d_36 "Manufacture of furniture; manufacturing n.e.c."
label var sector2d_37 "Recycling"
label var sector2d_40 "Electricity, gas, steam and hot water supply"
label var sector2d_41 "Collection, purification and distribution of water"
label var sector2d_45 "Construction"
label var sector2d_50 "Sale, maintenance and repair of motor vehicles and motorcycles; retail sale of automotive fuel"
label var sector2d_51 "Wholesale trade and commission trade, except of motor vehicles and motorcycles"
label var sector2d_52 "Retail trade, except of motor vehicles and motorcycles; repair of personal and household goods"
label var sector2d_55 "Hotels and restaurants"
label var sector2d_60 "Land transport; transport via pipelines"
label var sector2d_61 "Water transport"
label var sector2d_62 "Air transport"
label var sector2d_63 "Supporting and auxiliary transport activities; activities of travel agencies"
label var sector2d_64 "Post and telecommunications"
label var sector2d_65 "Financial intermediation, except insurance and pension funding"
label var sector2d_66 "Insurance and pension funding, except compulsory social security"
label var sector2d_67 "Activities auxiliary to financial intermediation"
label var sector2d_70 "Real estate activities"
label var sector2d_71 "Renting of machinery and equipment without operator and of personal and household goods"
label var sector2d_72 "Computer and related activities"
label var sector2d_73 "Research and development"
label var sector2d_74 "Other business activities"
label var sector2d_90 "Sewage and refuse disposal, sanitation and similar activities"
label var sector2d_91 "Activities of membership organizations n.e.c."
label var sector2d_92 "Recreational, cultural and sporting activities"
label var sector2d_93 "Other service activities"
label var sector2d_95 "Activities of private households as employers of domestic staff"

* Dates
label define lbl_date 1 "January 2004"
label define lbl_date 2 "February 2004", add
label define lbl_date 3 "March 2004", add
label define lbl_date 4 "April 2004", add
label define lbl_date 5 "May 2004", add
label define lbl_date 6 "June 2004", add
label define lbl_date 7 "July 2004", add
label define lbl_date 8 "August 2004", add
label define lbl_date 9 "September 2004", add
label define lbl_date 10 "October 2004", add
label define lbl_date 11 "November 2004", add
label define lbl_date 12 "December 2004", add
label define lbl_date 13 "January 2005", add
label define lbl_date 14 "February 2005", add
label define lbl_date 15 "March 2005", add
label define lbl_date 16 "April 2005", add
label define lbl_date 17 "May 2005", add
label define lbl_date 18 "June 2005", add
label define lbl_date 19 "July 2005", add
label define lbl_date 20 "August 2005", add
label define lbl_date 21 "September 2005", add
label define lbl_date 22 "October 2005", add
label define lbl_date 23 "November 2005", add
label define lbl_date 24 "December 2005", add
label define lbl_date 25 "January 2006", add
label define lbl_date 26 "February 2006", add
label define lbl_date 27 "March 2006", add
label define lbl_date 28 "April 2006", add
label define lbl_date 29 "May 2006", add
label define lbl_date 30 "June 2006", add
label define lbl_date 31 "July 2006", add
label define lbl_date 32 "August 2006", add
label define lbl_date 33 "September 2006", add
label define lbl_date 34 "October 2006", add
label define lbl_date 35 "November 2006", add
label define lbl_date 36 "December 2006", add
label define lbl_date 37 "January 2007", add
label define lbl_date 38 "February 2007", add
label define lbl_date 39 "March 2007", add
label define lbl_date 40 "April 2007", add
label define lbl_date 41 "May 2007", add
label define lbl_date 42 "June 2007", add
label define lbl_date 43 "July 2007", add
label define lbl_date 44 "August 2007", add
label define lbl_date 45 "September 2007", add
label define lbl_date 46 "October 2007", add
label define lbl_date 47 "November 2007", add
label define lbl_date 48 "December 2007", add
label define lbl_date 49 "January 2008", add
label define lbl_date 50 "February 2008", add
label define lbl_date 51 "March 2008", add
label define lbl_date 52 "April 2008", add
label define lbl_date 53 "May 2008", add
label define lbl_date 54 "June 2008", add
label define lbl_date 55 "July 2008", add
label define lbl_date 56 "August 2008", add
label define lbl_date 57 "September 2008", add
label define lbl_date 58 "October 2008", add
label define lbl_date 59 "November 2008", add
label define lbl_date 60 "December 2008", add
label define lbl_date 61 "January 2009", add
label define lbl_date 62 "February 2009", add
label define lbl_date 63 "March 2009", add
label define lbl_date 64 "April 2009", add
label define lbl_date 65 "May 2009", add
label define lbl_date 66 "June 2009", add
label define lbl_date 67 "July 2009", add
label define lbl_date 68 "August 2009", add
label define lbl_date 69 "September 2009", add
label define lbl_date 70 "October 2009", add
label define lbl_date 71 "November 2009", add
label define lbl_date 72 "December 2009", add
label values date lbl_date

* Date indicators
label var date_1 "January 2004"
label var date_2 "February 2004"
label var date_3 "March 2004"
label var date_4 "April 2004"
label var date_5 "May 2004"
label var date_6 "June 2004"
label var date_7 "July 2004"
label var date_8 "August 2004"
label var date_9 "September 2004"
label var date_10 "October 2004"
label var date_11 "November 2004"
label var date_12 "December 2004"
label var date_13 "January 2005"
label var date_14 "February 2005"
label var date_15 "March 2005"
label var date_16 "April 2005"
label var date_17 "May 2005"
label var date_18 "June 2005"
label var date_19 "July 2005"
label var date_20 "August 2005"
label var date_21 "September 2005"
label var date_22 "October 2005"
label var date_23 "November 2005"
label var date_24 "December 2005"
label var date_25 "January 2006"
label var date_26 "February 2006"
label var date_27 "March 2006"
label var date_28 "April 2006"
label var date_29 "May 2006"
label var date_30 "June 2006"
label var date_31 "July 2006"
label var date_32 "August 2006"
label var date_33 "September 2006"
label var date_34 "October 2006"
label var date_35 "November 2006"
label var date_36 "December 2006"
label var date_37 "January 2007"
label var date_38 "February 2007"
label var date_39 "March 2007"
label var date_40 "April 2007"
label var date_41 "May 2007"
label var date_42 "June 2007"
label var date_43 "July 2007"
label var date_44 "August 2007"
label var date_45 "September 2007"
label var date_46 "October 2007"
label var date_47 "November 2007"
label var date_48 "December 2007"
label var date_49 "January 2008"
label var date_50 "February 2008"
label var date_51 "March 2008"
label var date_52 "April 2008"
label var date_53 "May 2008"
label var date_54 "June 2008"
label var date_55 "July 2008"
label var date_56 "August 2008"
label var date_57 "September 2008"
label var date_58 "October 2008"
label var date_59 "November 2008"
label var date_60 "December 2008"
label var date_61 "January 2009"
label var date_62 "February 2009"
label var date_63 "March 2009"
label var date_64 "April 2009"
label var date_65 "May 2009"
label var date_66 "June 2009"
label var date_67 "July 2009"
label var date_68 "August 2009"
label var date_69 "September 2009"
label var date_70 "October 2009"
label var date_71 "November 2009"
label var date_72 "December 2009"
